netapp_ontap.models.software_status_details API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.software_status_details`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SoftwareStatusDetailsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SoftwareStatusDetails object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: SoftwareStatusDetailsReferenceAction GET`

    The action field of the software_status_details.

  `end_time: ImpreciseDateTime GET`

    End time for each status phase.

    Example: 2019-02-02T19:00:00.000+0000

  `issue: SoftwareStatusDetailsReferenceIssue GET`

    The issue field of the software_status_details.

  `name: str GET`

    Name of the phase to be retrieved for status details.

    Example: initialize

  `node: SoftwareStatusDetailsReferenceNode GET POST PATCH`

    The node field of the software_status_details.

  `start_time: ImpreciseDateTime GET`

    Start time for each status phase.

    Example: 2019-02-02T19:00:00.000+0000

  `state: str GET`

    Status of the phase

    Valid choices:

    - in_progress
    - waiting
    - paused_by_user
    - paused_on_error
    - completed
    - canceled
    - failed
    - pause_pending
    - cancel_pending